<?php

namespace Kylin\Licensing\Enums;

/**
 * 许可证状态
 */
enum LicenseStatus: int
{
    case Disabled = 0;
    case Active = 1;
    case Expired = 2;
    case Suspended = 3;
    case Revoked = 4;

    public function label(): string
    {
        return match ($this) {
            self::Disabled => '已禁用',
            self::Active => '有效',
            self::Expired => '已过期',
            self::Suspended => '已暂停',
            self::Revoked => '已吊销',
        };
    }
}
