<?php

namespace Kylin\Licensing\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * @method static array getStatusSummary()
 * @method static array activate(string $licenseKey, ?string $domain = null, ?string $ip = null)
 * @method static bool deactivate()
 */
class KylinLicensing extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-licensing';
    }
}
