<?php

use Illuminate\Support\Facades\Route;
use Kylin\Licensing\Http\Controllers\LicenseController;

Route::prefix('kylin/licensing')->group(function () {
    Route::get('/status', [LicenseController::class, 'status']);
    Route::post('/activate', [LicenseController::class, 'activate']);
    Route::delete('/deactivate', [LicenseController::class, 'deactivate']);
});
